#
# spec file for package pantheon-agent-polkit
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         appid io.elementary.desktop.agent-polkit
Name:           pantheon-agent-polkit
Version:        8.0.1
Release:        1.1
Summary:        Polkit authorization designed for Pantheon
License:        LGPL-2.1-or-later
URL:            https://github.com/elementary/pantheon-agent-polkit
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libadwaita-1)
BuildRequires:  pkgconfig(pantheon-wayland-1)
BuildRequires:  pkgconfig(polkit-agent-1)
BuildRequires:  pkgconfig(polkit-gobject-1)

%description
An agent for Polkit authorization designed for Pantheon desktop environment.

%lang_package

%prep
%autosetup

%build
%meson
%meson_build

%install
%meson_install
%find_lang %{appid}
%fdupes -s %{buildroot}%{_datadir}

%if %{?suse_version} >= 1600
# move the xdg autostart file into /usr/etc
mkdir -p %{buildroot}%{_distconfdir}/xdg/autostart
mv %{buildroot}%{_sysconfdir}/xdg/autostart/%{appid}.desktop \
   %{buildroot}%{_distconfdir}/xdg/autostart/%{appid}.desktop
%endif

%files
%license COPYING
%doc README.md
%{_datadir}/applications/%{appid}.desktop
%{_libexecdir}/policykit-1-pantheon
%if %{?suse_version} >= 1600
%{_distconfdir}/xdg/autostart/%{appid}.desktop
%else
%{_sysconfdir}/xdg/autostart/%{appid}.desktop
%endif
%{_datadir}/metainfo/%{appid}.metainfo.xml

%files lang -f %{appid}.lang

%changelog
* Wed Nov 20 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Always on top and centered
  * Updated translations
* Tue Aug 13 2024 Richard Rahl <rrahl0@opensuse.org>
- add support for Leap
* Fri Aug  9 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * Update to the latest platform libraries
  * Updated translations
- update to 1.0.5:
  * Updated translations
- update to 1.0.4:
  * Updated translations
- update to 1.0.3:
  * Fix a potential issue when ending the session
  * Updated translations
- update to 1.0.2:
  * Updated translations
- update to 1.0.1:
  * Updated translations
- change url to github, as we don't want to link to their own OS
- move xdg autostart to /usr/etc
* Mon Nov 25 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 1.0.0:
  * Appdata (#52)
  * Add Release to Actions
  * Add Gettext Updates to Actions
  * Add Lint to CI (#50)
  * Fix code style issues
  * run installation in CI (#51)
  * Build with GitHub CI (#49)
  * Delete CODE_OF_CONDUCT.md
  * Delete FUNDING.yml
  * PolkitDialog: Rewrite as Granite.MessageDialog subclass (#46)
  * Fix DBus warning
  * PolkitDialog: Set InputPurpose to PASSWORD (#47)
  * Fix merge conflicts
  * Merge branch 'origin/master' into Weblate.
  * Create FUNDING.yml
* Mon Mar  4 2019 Alexei Podvalsky <avvissu@yandex.by>
- Update to 0.1.6:
  * Travis: use juno-unstable docker container
  * Add missing languages (#39)
  * Add pt and pt_BR to extra LINGUAS (#38)
  * Add pt and pt_BR to LINGUAS (#37)
  * Wrap error label (#36)
  * Meson: Use GLib preset for l10n
  * meson: add version string
* Sat Jun  9 2018 avvissu@yandex.by
- Update to 0.1.5:
  * Correctly handle the user dismissing the authentication
    dialog (#26)
  * RDNN to io.elementary (#28)
  * Add editorconfig file
  * Install daemon autostart to correct dir (#29)
  * Remove missed CMakeLists.txt
  * Generate po files for extra
  * Add Meson support (#18)
  * Prefer current user (#21)
  * Show default avatar alongside the name in the combobox (#17)
  * Show insensitive combo box when only one admin user instead
    of hiding it (#16)
  * Create .gitignore (#13)
  * Create CODE_OF_CONDUCT.md (#12)
* Fri Jun  8 2018 avvissu@yandex.by
- Switch to github
- Switch to meson
- Remove obsolete macros
- Spec file cleanup
* Sat May 27 2017 avvissu@yandex.by
- Update to 0.1.4:
  * Fix closing not cancelling (#11)
* Tue May  2 2017 avvissu@yandex.by
- Update to 0.1.3:
  * README.md: add basic project info (#10)
  * Add Travis CI (#9)
  * add license file (#5)
  * Fix #1 and #7 (#8)
  * Fix binary location (#3)
  * Fix binary install location
  * Add uncommited file
  * Replace pantheon-agent-polkit with EXEC_NAME
  * Create README.md
* Sun Feb 12 2017 avvissu@yandex.by
- Update to 0.1.2:
  * Launchpad automatic translations update.
  * Remove identity label to align identity combo with password
    entry
* Wed Dec  7 2016 avvissu@yandex.by
- Update to 0.1.1
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.1.0+bzr.35
- Change path to polkit
* Thu Aug  4 2016 avvissu@yandex.by
- Initial package
